==> haskell-text-metrics-0.3.2-140-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-metrics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-metrics
version:              0.3.2
visibility:           public
id:                   text-metrics-0.3.2-DXNij3qsxTC5l8GQjOFYt7
key:                  text-metrics-0.3.2-DXNij3qsxTC5l8GQjOFYt7
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/text-metrics
synopsis:             Calculate various string metrics efficiently
description:          Calculate various string metrics efficiently.
category:             Text, Algorithms
abi:                  d7bf21e0058bc52008d15f1d002d7a2e
exposed:              True
exposed-modules:      Data.Text.Metrics
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-metrics-0.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-metrics-0.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-metrics-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-metrics
hs-libraries:         HStext-metrics-0.3.2-DXNij3qsxTC5l8GQjOFYt7
depends:
    base-4.17.2.1 containers-0.6.7 text-2.0.2
    vector-0.13.2.0-B39FQf4cXUZ2GlwNF0TDTd

haddock-interfaces:
    /usr/share/doc/haskell-text-metrics/html/text-metrics.haddock

haddock-html:         /usr/share/doc/haskell-text-metrics/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-metrics-0.3.2-141-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-metrics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-metrics
version:              0.3.2
visibility:           public
id:                   text-metrics-0.3.2-2Modhn7Nzj2LI8ukWKxtEC
key:                  text-metrics-0.3.2-2Modhn7Nzj2LI8ukWKxtEC
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/text-metrics
synopsis:             Calculate various string metrics efficiently
description:          Calculate various string metrics efficiently.
category:             Text, Algorithms
abi:                  0480169ddb2161b90da429f35cef70b4
exposed:              True
exposed-modules:      Data.Text.Metrics
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-metrics-0.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-metrics-0.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-metrics-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-metrics
hs-libraries:         HStext-metrics-0.3.2-2Modhn7Nzj2LI8ukWKxtEC
depends:
    base-4.17.2.1 containers-0.6.7 text-2.0.2
    vector-0.13.2.0-cop25r7TnE5vewvd3oOyK

haddock-interfaces:
    /usr/share/doc/haskell-text-metrics/html/text-metrics.haddock

haddock-html:         /usr/share/doc/haskell-text-metrics/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
